@@ -28,6 +28,7 @@
 #include <arpa/inet.h>
 
 #include <spa/utils/string.h>
+#include <spa/utils/dict.h>
 #include <spa/pod/parser.h>
 #include <spa/param/props.h>
 #include <spa/param/audio/format.h>
@@ -38,7 +39,6 @@
 #include <ldacBT_abr.h>
 #endif
 
-#include "defs.h"
 #include "rtp.h"
 #include "a2dp-codecs.h"
 
@@ -150,7 +150,7 @@ static int codec_select_config(const struct a2dp_codec *codec, uint32_t flags,
         return sizeof(conf);
 }
 
-static int codec_enum_config(const struct a2dp_codec *codec,
+static int codec_enum_config(const struct a2dp_codec *codec, uint32_t flags,
 		const void *caps, size_t caps_size, uint32_t id, uint32_t idx,
 		struct spa_pod_builder *b, struct spa_pod **param)
 {
@@ -284,7 +284,7 @@ static int string_to_eqmid(const char * eqmid)
 		return LDACBT_EQMID_AUTO;
 }
 
-static void *codec_init_props(const struct a2dp_codec *codec, const struct spa_dict *settings)
+static void *codec_init_props(const struct a2dp_codec *codec, uint32_t flags, const struct spa_dict *settings)
 {
 	struct props *p = calloc(1, sizeof(struct props));
 	const char *str;
@@ -317,7 +317,7 @@ static int codec_enum_props(void *props, const struct spa_dict *settings, uint32
 			spa_pod_builder_push_object(b, &f[0], SPA_TYPE_OBJECT_PropInfo, id);
 			spa_pod_builder_prop(b, SPA_PROP_INFO_id, 0);
 			spa_pod_builder_id(b, SPA_PROP_quality);
-			spa_pod_builder_prop(b, SPA_PROP_INFO_name, 0);
+			spa_pod_builder_prop(b, SPA_PROP_INFO_description, 0);
 			spa_pod_builder_string(b, "LDAC quality");
 
 			spa_pod_builder_prop(b, SPA_PROP_INFO_type, 0);
@@ -469,10 +469,10 @@ static void *codec_init(const struct a2dp_codec *codec, uint32_t flags,
 error_errno:
 	res = -errno;
 error:
-	if (this->ldac)
+	if (this && this->ldac)
 		ldacBT_free_handle(this->ldac);
 #ifdef ENABLE_LDAC_ABR
-	if (this->ldac_abr)
+	if (this && this->ldac_abr)
 		ldac_ABR_free_handle(this->ldac_abr);
 #endif
 	free(this);
@@ -565,7 +565,7 @@ static int codec_encode(void *data,
 	*dst_out = dst_used;
 
 	this->payload->frame_count += frame_num;
-	*need_flush = this->payload->frame_count > 0;
+	*need_flush = (this->payload->frame_count > 0) ? NEED_FLUSH_ALL : NEED_FLUSH_NO;
 
 	return src_used;
 }
@@ -597,3 +597,8 @@ const struct a2dp_codec a2dp_codec_ldac = {
 	.reduce_bitpool = codec_reduce_bitpool,
 	.increase_bitpool = codec_increase_bitpool,
 };
+
+A2DP_CODEC_EXPORT_DEF(
+	"ldac",
+	&a2dp_codec_ldac
+);
